=== modified file 'lib/lp/app/javascript/subscribers/subscribers_list.js'
--- lib/lp/app/javascript/subscribers/subscribers_list.js	2011-08-30 12:41:13 +0000
+++ lib/lp/app/javascript/subscribers/subscribers_list.js	2011-09-16 00:11:16 +0000
@@ -85,6 +85,7 @@
     }
     this.subscriber_levels = config.subscriber_levels;
     var sl = this.subscribers_list = new SubscribersList(config);
+    sl.container_node.setData('subscribers_loader', this);
 
     if (!Y.Lang.isValue(config.context) ||
         !Y.Lang.isString(config.context.web_link)) {
@@ -211,6 +212,7 @@
         Y.error('Got non-array "'+ details +
                 '" in _loadSubscribersFromList().');
     }
+    this.subscribers_list.container_node.empty();
     var index, subscriber;
     for (index = 0; index < details.length; index++) {
         subscriber = details[index].subscriber;

=== modified file 'lib/lp/app/javascript/subscribers/tests/test_subscribers_list.js'
--- lib/lp/app/javascript/subscribers/tests/test_subscribers_list.js	2011-08-30 12:57:38 +0000
+++ lib/lp/app/javascript/subscribers/tests/test_subscribers_list.js	2011-09-15 11:24:46 +0000
@@ -1579,6 +1579,9 @@
             loader.subscribers_list instanceof module.SubscribersList);
         Y.Assert.isNotNull(loader.error_handler);
         Y.Assert.isTrue(loading_started);
+        var container_node = Y.one('#other-subscribers-container');
+        Y.Assert.areEqual(
+                loader, container_node.getData('subscribers_loader'));
 
         // Restore original method.
         module.SubscribersLoader.prototype._loadSubscribers = old_load;

=== modified file 'lib/lp/bugs/browser/bug.py'
--- lib/lp/bugs/browser/bug.py	2011-09-12 01:27:24 +0000
+++ lib/lp/bugs/browser/bug.py	2011-09-15 11:24:46 +0000
@@ -89,6 +89,7 @@
 from lp.app.errors import NotFoundError
 from lp.app.widgets.itemswidgets import LaunchpadRadioWidgetWithDescription
 from lp.app.widgets.project import ProjectScopeWidget
+from lp.bugs.browser.bugsubscription import BugPortletSubscribersWithDetails
 from lp.bugs.browser.widgets.bug import BugTagsWidget
 from lp.bugs.enum import BugNotificationLevel
 from lp.bugs.interfaces.bug import (
@@ -103,6 +104,7 @@
 from lp.bugs.interfaces.bugtask import (
     BugTaskSearchParams,
     BugTaskStatus,
+    IBugTask,
     IFrontPageBugTaskSearch,
     )
 from lp.bugs.interfaces.bugwatch import IBugWatchSet
@@ -870,18 +872,34 @@
             notify(ObjectModifiedEvent(
                     bug, bug_before_modification, changed_fields))
         if self.request.is_ajax:
-            if private_changed:
+            if private_changed or security_related_changed:
                 return self._getSubscriptionDetails()
             else:
                 return ''
 
     def _getSubscriptionDetails(self):
         cache = dict()
+        # The subscription details for the current user.
         self.extractBugSubscriptionDetails(self.user, self.context.bug, cache)
-        return dumps(
+
+        # The subscription details for other users to populate the subscribers
+        # list in the portlet.
+        if IBugTask.providedBy(self.context):
+            bug = self.context.bug
+        else:
+            bug = self.context
+        subscribers_portlet = BugPortletSubscribersWithDetails(
+            bug, self.request)
+        subscription_data = subscribers_portlet()
+        cache_data = dumps(
             cache, cls=ResourceJSONEncoder,
             media_type=EntryResource.JSON_TYPE)
 
+        return """{
+            "cache_data": %s,
+            "subscription_data": %s}
+            """ % (cache_data, subscription_data)
+
     def _handlePrivacyChanged(self, user_will_be_subscribed):
         """Handle the case where the privacy of the bug has been changed.
 

=== modified file 'lib/lp/bugs/browser/tests/test_bug_views.py'
--- lib/lp/bugs/browser/tests/test_bug_views.py	2011-09-12 01:24:44 +0000
+++ lib/lp/bugs/browser/tests/test_bug_views.py	2011-09-15 05:31:43 +0000
@@ -7,6 +7,7 @@
 
 import simplejson
 from zope.component import getUtility
+from zope.security.proxy import removeSecurityProxy
 
 from BeautifulSoup import BeautifulSoup
 
@@ -273,7 +274,8 @@
         # When the bug secrecy view is called from an ajax request, it should
         # provide a json encoded dict when rendered. The dict contains bug
         # subscription information resulting from the update to the bug
-        # privacy.
+        # privacy as well as information used to populate the updated
+        # subscribers list.
         person = self.factory.makePerson()
         bug = self.factory.makeBug(owner=person)
         with person_logged_in(person):
@@ -287,7 +289,9 @@
                 'field.security_related': 'off'},
             **extra)
         view = self.createInitializedSecrecyView(person, bug, request)
-        cache_data = simplejson.loads(view.render())
+        result_data = simplejson.loads(view.render())
+
+        cache_data = result_data['cache_data']
         self.assertFalse(cache_data['other_subscription_notifications'])
         subscription_data = cache_data['subscription']
         self.assertEqual(
@@ -299,6 +303,12 @@
         self.assertEqual(
             'Discussion', subscription_data['bug_notification_level'])
 
+        [subscriber_data] = result_data['subscription_data']
+        subscriber = removeSecurityProxy(bug.default_bugtask).pillar.owner
+        self.assertEqual(
+            subscriber.name, subscriber_data['subscriber']['name'])
+        self.assertEqual('Discussion', subscriber_data['subscription_level'])
+
     def test_set_security_related(self):
         # Test that the bug attribute 'security_related' can be updated
         # using the view.

=== modified file 'lib/lp/bugs/javascript/bugtask_index.js'
--- lib/lp/bugs/javascript/bugtask_index.js	2011-09-14 08:59:04 +0000
+++ lib/lp/bugs/javascript/bugtask_index.js	2011-09-16 00:11:16 +0000
@@ -366,14 +366,26 @@
     qs = Y.lp.client.append_qs(qs, 'field.private', private_flag?'on':'off');
     qs = Y.lp.client.append_qs(
         qs, 'field.security_related', security_related?'on':'off');
+    var sub_list_node = Y.one('#other-bug-subscribers');
+    var subscribers_list = sub_list_node.getData('subscribers_loader');
     var config = {
         method: "POST",
         headers: {'Accept': 'application/xhtml'},
         data: qs,
         on: {
+            start: function () {
+                subscribers_list.subscribers_list.startActivity(
+                    'Updating subscribers...')
+            },
+            end: function () {
+                subscribers_list.subscribers_list.stopActivity();
+            },
             success: function (id, response) {
                 if (response.responseText !== '') {
-                    var cache_data = Y.JSON.parse(response.responseText);
+                    var result_data = Y.JSON.parse(response.responseText);
+                    var subscribers = result_data.subscription_data;
+                    subscribers_list._loadSubscribersFromList(subscribers);
+                    var cache_data = result_data.cache_data;
                     var item;
                     for (item in cache_data) {
                         if (cache_data.hasOwnProperty(item)) {
@@ -429,7 +441,7 @@
                     }
                 }
                 Y.lp.client.display_notifications(
-                        response.getResponseHeader('X-Lazr-Notifications'));
+                    response.getResponseHeader('X-Lazr-Notifications'));
                 Y.lp.anim.green_flash({node: privacy_div}).run();
             },
             failure: error_handler.getFailureHandler()

